"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var utils_1 = require("./utils");
function api(asyncTypeName, config) {
    if (config === void 0) { config = {}; }
    return function (target, key, descriptor) {
        config.asyncTypeName = asyncTypeName;
        if (typeof config.axiosApi !== 'undefined') {
            config.axiosApi = Boolean(config.axiosApi);
        }
        else {
            config.axiosApi = true;
        }
        descriptor.value.$apiConfig = config;
        descriptor.value.$bind = true;
        return descriptor;
    };
}
exports.api = api;
function bind(target, key, descriptor) {
    descriptor.value.$bind = true;
    return descriptor;
}
exports.bind = bind;
function typeDef(target, key) {
    if (typeof target === 'function') {
        // static type
        var namespace = target.name;
        target[key] = namespace + "/" + key;
        // console.warn('typeDef is not compatible with static field.');
        return target;
    }
    else {
        // instance type
        return {
            get: function () {
                var cacheKey = '__' + key;
                if (!this[cacheKey]) {
                    var namespace = this.constructor.name;
                    this[cacheKey] = namespace + "<" + this.key + ">/" + key;
                }
                return this[cacheKey];
            }
        };
    }
}
exports.typeDef = typeDef;
function asyncTypeDef(target, key) {
    if (typeof target === 'function') {
        // const namespace = target.name;
        // target[key] = getAsyncType(key, namespace);
        console.warn('asyncTypeDef is not compatible with static field.');
        return target;
    }
    else {
        return {
            get: function () {
                var cacheKey = '__' + key;
                if (!this[cacheKey]) {
                    var namespace = this.constructor.name;
                    this[cacheKey] = utils_1.getAsyncType(key, namespace, this.key);
                }
                return this[cacheKey];
            }
        };
    }
}
exports.asyncTypeDef = asyncTypeDef;
/**
 * 在初始化store完成后自动执行该saga方法
 * @param target
 * @param {string} key
 * @param descriptor
 * @returns {any}
 */
function runSaga(target, key, descriptor) {
    descriptor.value.$runSaga = true;
    descriptor.value.$bind = true;
    return descriptor;
}
exports.runSaga = runSaga;
//# sourceMappingURL=decorators.js.map